ExecutionControllerLocalServerHandler

Trait ExecutionControllerLocalServerHandler 

pub trait ExecutionControllerLocalServerHandler<___T: Transport = Channel> {
    // Required method
    fn stop(&mut self) -> impl Future<Output = ()>;

    // Provided method
    fn on_unknown_interaction(
        &mut self,
        ordinal: u64,
    ) -> impl Future<Output = ()> { ... }
}
A server handler for the ExecutionController protocol.

See ExecutionController for more details.

Required Methods

fn stop(&mut self) -> impl Future<Output = ()>

Initiates a stop action on this component. Once complete, OnStop will be called with the stopped payload and this channel is closed.

Note that a component may stop running on its own at any time, so it is possible for OnStop to be received before Stop is called.

Provided Methods

fn on_unknown_interaction(&mut self, ordinal: u64) -> impl Future<Output = ()>

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<___H, ___T> ExecutionControllerLocalServerHandler<___T> for Local<___H>
where ___H: ExecutionControllerServerHandler<___T>, ___T: Transport,

Source

async fn stop(&mut self)

Source

async fn on_unknown_interaction(&mut self, ordinal: u64)

Implementors